==> haskell-hasql-pool-0.5.2-294-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-pool
version:              0.5.2
visibility:           public
id:                   hasql-pool-0.5.2-8f6wntpOicA1OhVgs7prik
key:                  hasql-pool-0.5.2-8f6wntpOicA1OhVgs7prik
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool 
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  f59ff7895ea8a14ce4d2922919f68361
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hasql-pool-0.5.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hasql-pool-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/hasql-pool-0.5.2
hs-libraries:         HShasql-pool-0.5.2-8f6wntpOicA1OhVgs7prik
depends:
    base-prelude-1.4-2BOM8BPgshJ3XugpQGCzYd
    hasql-1.4.5.3-HKzFPaPDN6lJfRPEpZHjco
    resource-pool-0.2.3.2-92Fv65IbMqn7OqZYAAuwGN time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.5.2-298-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-pool
version:              0.5.2
visibility:           public
id:                   hasql-pool-0.5.2-WzBMSfk3BIHFKKvUI0h1M
key:                  hasql-pool-0.5.2-WzBMSfk3BIHFKKvUI0h1M
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool 
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  0c11a1e4a51bd97e21343378f9b8b23c
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hasql-pool-0.5.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hasql-pool-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/hasql-pool-0.5.2
hs-libraries:         HShasql-pool-0.5.2-WzBMSfk3BIHFKKvUI0h1M
depends:
    base-prelude-1.4-2BOM8BPgshJ3XugpQGCzYd
    hasql-1.4.5.3-LF1G04nHcUdDp7qkRvAulQ
    resource-pool-0.2.3.2-5R9Nz9N4r5Z8fBahgu7RL2 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
